@@ -104,9 +104,11 @@ class IncrementalTextLayout(TextLayout, EventDispatcher):
     _width: int
     _height: int
 
-    def __init__(self, document: AbstractDocument, width: int, height: int, x: float = 0, y: float = 0, z: float = 0,  # noqa: D107
-                 anchor_x: AnchorX = "left", anchor_y: AnchorY = "bottom", rotation: float = 0, multiline: bool = False,
-                 dpi: int | None = None, batch: Batch | None = None, group: Group | None = None,
+    def __init__(self, document: AbstractDocument,
+                 x: float = 0, y: float = 0, z: float = 0,
+                 width: int = None, height: int = None,
+                 anchor_x: AnchorX = 'left', anchor_y: AnchorY = 'bottom', rotation: float = 0, multiline: bool = False,
+                 dpi: float | None = None, batch: Batch | None = None, group: Group | None = None,
                  program: ShaderProgram | None = None, wrap_lines: bool = True) -> None:
 
         if width is None or height is None:
@@ -129,7 +131,7 @@ class IncrementalTextLayout(TextLayout, EventDispatcher):
 
         self._owner_runs = runlist.RunList(0, None)
 
-        super().__init__(document, width, height, x, y, z, anchor_x, anchor_y, rotation, multiline, dpi, batch, group,
+        super().__init__(document, x, y, z, width, height, anchor_x, anchor_y, rotation, multiline, dpi, batch, group,
                          program, wrap_lines)
 
     def _update_scissor_area(self) -> None:
@@ -209,7 +211,7 @@ class IncrementalTextLayout(TextLayout, EventDispatcher):
         self._update()
 
     def on_style_text(self, start: int, end: int, attributes: dict[str, Any]) -> None:
-        if "font_name" in attributes or "font_size" in attributes or "bold" in attributes or "italic" in attributes:
+        if "font_name" in attributes or "font_size" in attributes or "weight" in attributes or "italic" in attributes:
             self._invalid_glyphs.invalidate(start, end)
         elif "color" in attributes or "background_color" in attributes:
             self._invalid_style.invalidate(start, end)
